Cloud Network - Nautobot Documentation

Skip to content

# Cloud Networks

Cloud networks in Nautobot refer to the interconnected infrastructure and communication pathways that enable data transmission and access to cloud services. Common cloud networks are Amazon/Google virtual private clouds (VPCs), Azure virtual networks, multi-cloud networks, etc.

Each cloud network must have a unique name and must be assigned to a cloud resource type and a cloud account. Each cloud network can also be linked to a parent cloud network that is not a child of other cloud networks. One or more prefixes can be optionally assigned to cloud networks, and this many to many relationship is represented by the CloudNetworkPrefixAssignment model.